@@ -1,6 +1,20 @@
+__tool_name__ = 'hackingtools'
 from .core import Connections as __Connections
 from .core import Config, Utils, Logger, Repositories, Objects
 
+# Check Version Update
+import pkg_resources as __pkg
+__version__ = __pkg.get_distribution(__tool_name__).version
+import requests as __req 
+from bs4 import BeautifulSoup as __bs4
+__pypipage__ = requests.get("https://pypi.org/project/hackingtools/")
+if __pypipage__.status_code == 200:
+    __pageContent = __bs4(__pypipage__.content, 'html.parser'))
+    __pypiVersion = __pageContent.find('h1', {'class' : 'package-header__name'}).replace(__tool_name__, '').replace(' ', '')
+    if not __version__ == __pypiVersion:
+        Logger.printMessage('Version outdated... Newer version available: {v}'.format(v=__pypiVersion), is_warn=True)
+
+
 __config__ = Config.getConfig(parentKey='core', key='import_modules')
 
 import os as __os
